THE BOOST MPL LIBRARY: Iterator Protocol

Front Page / Changelog & History / Changes in Boost 1.32.0 Release / Iterator Protocol

# Iterator Protocol

The library no longer guarantees or relies on the direct presence of `advance` / `distance` / `next` / `prior` / `type` members in iterator types; the following table summarises the new requirements:

Before | Now
--- | ---
`i::type` | `deref<i>::type`
`i::next` | `next<i>::type`
`i::prior` | `prior<i>::type`
`i::advance<n>::type` | `advance<i,n>::type`
`i::distance<j>::type` | `distance<i,j>::type`
`i::category` | `i::category`